@@ -1,10 +1,10 @@
 from simpleicons.icon import Icon
-icon= Icon(
+linuxfoundation_icon= Icon(
     title="Linux Foundation",
     slug="linuxfoundation",
     hex="003366",
     source="https://www.linuxfoundation.org/en/about/brand/",
-    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Linux Foundation icon</title><path d="M4.8 19.2h9.6V24H0V9.6h4.8v9.6zM0 0v7.2h4.8V4.822h14.4V19.2h-2.4V24H24V0H0z"/></svg>""",
+    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Linux Foundation</title><path d="M4.8 19.2h9.6V24H0V9.6h4.8v9.6zM0 0v7.2h4.8V4.822h14.4V19.2h-2.4V24H24V0H0z"/></svg>""",
     guidelines='https://www.linuxfoundation.org/en/about/brand/',
     license=None,
 )
